package com.phm.manage.service.impl;

import com.phm.manage.domain.PreHandleResult;
import com.phm.manage.mapper.PreHandleResultMapper;
import com.phm.manage.service.IPreHandleResultService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 数据预处理结果Service业务层处理
 *
 * @author phm
 * @date 2023-08-22
 */
@Service
public class PreHandleResultServiceImpl implements IPreHandleResultService {
    @Autowired
    private PreHandleResultMapper preHandleResultMapper;

    /**
     * 查询数据预处理结果
     *
     * @param id 数据预处理结果主键
     * @return 数据预处理结果
     */
    @Override
    public PreHandleResult selectPreHandleResultById(Long id) {
        return preHandleResultMapper.selectPreHandleResultById(id);
    }

    /**
     * 查询数据预处理结果列表
     *
     * @param preHandleResult 数据预处理结果
     * @return 数据预处理结果
     */
    @Override
    public List<PreHandleResult> selectPreHandleResultList(PreHandleResult preHandleResult) {
        return preHandleResultMapper.selectPreHandleResultList(preHandleResult);
    }

    /**
     * 新增数据预处理结果
     *
     * @param preHandleResult 数据预处理结果
     * @return 结果
     */
    @Override
    public int insertPreHandleResult(PreHandleResult preHandleResult) {
        return preHandleResultMapper.insertPreHandleResult(preHandleResult);
    }

    /**
     * 修改数据预处理结果
     *
     * @param preHandleResult 数据预处理结果
     * @return 结果
     */
    @Override
    public int updatePreHandleResult(PreHandleResult preHandleResult) {
        return preHandleResultMapper.updatePreHandleResult(preHandleResult);
    }

    /**
     * 批量删除数据预处理结果
     *
     * @param ids 需要删除的数据预处理结果主键
     * @return 结果
     */
    @Override
    public int deletePreHandleResultByIds(Long[] ids) {
        return preHandleResultMapper.deletePreHandleResultByIds(ids);
    }

    /**
     * 删除数据预处理结果信息
     *
     * @param id 数据预处理结果主键
     * @return 结果
     */
    @Override
    public int deletePreHandleResultById(Long id) {
        return preHandleResultMapper.deletePreHandleResultById(id);
    }
}
